# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .service_agreement_pb2 import GetServiceAgreementRequest, GetServiceAgreementResponse

__all__ = [
    "DomainServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class DomainServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _DomainServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _DomainServiceAsyncStub: ...  # type: ignore
    def GetServiceAgreement(self, __1: GetServiceAgreementRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetServiceAgreementResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetServiceAgreementResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _DomainServiceBlockingStub(DomainServiceStub):
    def GetServiceAgreement(self, __1: GetServiceAgreementRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetServiceAgreementResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _DomainServiceAsyncStub(DomainServiceStub):
    def GetServiceAgreement(self, __1: GetServiceAgreementRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetServiceAgreementResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import synchronizer_connectivity_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in com/digitalasset/canton/admin/participant/v30/synchronizer_connectivity_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SynchronizerConnectivityServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ConnectSynchronizer = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/ConnectSynchronizer',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ConnectSynchronizerRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ConnectSynchronizerResponse.FromString,
                _registered_method=True)
        self.RegisterSynchronizer = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/RegisterSynchronizer',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.RegisterSynchronizerRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.RegisterSynchronizerResponse.FromString,
                _registered_method=True)
        self.ReconnectSynchronizers = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/ReconnectSynchronizers',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ReconnectSynchronizersRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ReconnectSynchronizersResponse.FromString,
                _registered_method=True)
        self.ReconnectSynchronizer = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/ReconnectSynchronizer',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ReconnectSynchronizerRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ReconnectSynchronizerResponse.FromString,
                _registered_method=True)
        self.ModifySynchronizer = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/ModifySynchronizer',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ModifySynchronizerRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ModifySynchronizerResponse.FromString,
                _registered_method=True)
        self.DisconnectSynchronizer = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/DisconnectSynchronizer',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.DisconnectSynchronizerRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.DisconnectSynchronizerResponse.FromString,
                _registered_method=True)
        self.DisconnectAllSynchronizers = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/DisconnectAllSynchronizers',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.DisconnectAllSynchronizersRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.DisconnectAllSynchronizersResponse.FromString,
                _registered_method=True)
        self.Logout = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/Logout',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.LogoutRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.LogoutResponse.FromString,
                _registered_method=True)
        self.ListConnectedSynchronizers = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/ListConnectedSynchronizers',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ListConnectedSynchronizersRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ListConnectedSynchronizersResponse.FromString,
                _registered_method=True)
        self.ListRegisteredSynchronizers = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/ListRegisteredSynchronizers',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ListRegisteredSynchronizersRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ListRegisteredSynchronizersResponse.FromString,
                _registered_method=True)
        self.GetSynchronizerId = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/GetSynchronizerId',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.GetSynchronizerIdRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.GetSynchronizerIdResponse.FromString,
                _registered_method=True)


class SynchronizerConnectivityServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ConnectSynchronizer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterSynchronizer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReconnectSynchronizers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReconnectSynchronizer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModifySynchronizer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisconnectSynchronizer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisconnectAllSynchronizers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Logout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListConnectedSynchronizers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRegisteredSynchronizers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSynchronizerId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SynchronizerConnectivityServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ConnectSynchronizer': grpc.unary_unary_rpc_method_handler(
                    servicer.ConnectSynchronizer,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ConnectSynchronizerRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ConnectSynchronizerResponse.SerializeToString,
            ),
            'RegisterSynchronizer': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterSynchronizer,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.RegisterSynchronizerRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.RegisterSynchronizerResponse.SerializeToString,
            ),
            'ReconnectSynchronizers': grpc.unary_unary_rpc_method_handler(
                    servicer.ReconnectSynchronizers,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ReconnectSynchronizersRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ReconnectSynchronizersResponse.SerializeToString,
            ),
            'ReconnectSynchronizer': grpc.unary_unary_rpc_method_handler(
                    servicer.ReconnectSynchronizer,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ReconnectSynchronizerRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ReconnectSynchronizerResponse.SerializeToString,
            ),
            'ModifySynchronizer': grpc.unary_unary_rpc_method_handler(
                    servicer.ModifySynchronizer,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ModifySynchronizerRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ModifySynchronizerResponse.SerializeToString,
            ),
            'DisconnectSynchronizer': grpc.unary_unary_rpc_method_handler(
                    servicer.DisconnectSynchronizer,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.DisconnectSynchronizerRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.DisconnectSynchronizerResponse.SerializeToString,
            ),
            'DisconnectAllSynchronizers': grpc.unary_unary_rpc_method_handler(
                    servicer.DisconnectAllSynchronizers,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.DisconnectAllSynchronizersRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.DisconnectAllSynchronizersResponse.SerializeToString,
            ),
            'Logout': grpc.unary_unary_rpc_method_handler(
                    servicer.Logout,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.LogoutRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.LogoutResponse.SerializeToString,
            ),
            'ListConnectedSynchronizers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConnectedSynchronizers,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ListConnectedSynchronizersRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ListConnectedSynchronizersResponse.SerializeToString,
            ),
            'ListRegisteredSynchronizers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRegisteredSynchronizers,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ListRegisteredSynchronizersRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ListRegisteredSynchronizersResponse.SerializeToString,
            ),
            'GetSynchronizerId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSynchronizerId,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.GetSynchronizerIdRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.GetSynchronizerIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SynchronizerConnectivityService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ConnectSynchronizer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/ConnectSynchronizer',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ConnectSynchronizerRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ConnectSynchronizerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterSynchronizer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/RegisterSynchronizer',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.RegisterSynchronizerRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.RegisterSynchronizerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReconnectSynchronizers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/ReconnectSynchronizers',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ReconnectSynchronizersRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ReconnectSynchronizersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReconnectSynchronizer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/ReconnectSynchronizer',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ReconnectSynchronizerRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ReconnectSynchronizerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ModifySynchronizer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/ModifySynchronizer',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ModifySynchronizerRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ModifySynchronizerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DisconnectSynchronizer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/DisconnectSynchronizer',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.DisconnectSynchronizerRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.DisconnectSynchronizerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DisconnectAllSynchronizers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/DisconnectAllSynchronizers',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.DisconnectAllSynchronizersRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.DisconnectAllSynchronizersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Logout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/Logout',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.LogoutRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.LogoutResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListConnectedSynchronizers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/ListConnectedSynchronizers',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ListConnectedSynchronizersRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ListConnectedSynchronizersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListRegisteredSynchronizers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/ListRegisteredSynchronizers',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ListRegisteredSynchronizersRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.ListRegisteredSynchronizersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSynchronizerId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.SynchronizerConnectivityService/GetSynchronizerId',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.GetSynchronizerIdRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2.GetSynchronizerIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="SynchronizerTime")


@_attrs_define
class SynchronizerTime:
    """
    Attributes:
        synchronizer_id (str): The id of the synchronizer.
            Required
        record_time (str | Unset): All commands with a maximum record time below this value MUST be considered lost if
            their completion has not arrived before this checkpoint.
            Required
    """

    synchronizer_id: str
    record_time: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        synchronizer_id = self.synchronizer_id

        record_time = self.record_time

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "synchronizerId": synchronizer_id,
            }
        )
        if record_time is not UNSET:
            field_dict["recordTime"] = record_time

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        synchronizer_id = d.pop("synchronizerId")

        record_time = d.pop("recordTime", UNSET)

        synchronizer_time = cls(
            synchronizer_id=synchronizer_id,
            record_time=record_time,
        )

        synchronizer_time.additional_properties = d
        return synchronizer_time

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
"""
This module contains the mapping between Protobuf objects and Python/dazl types.
"""

from __future__ import annotations

# Earlier versions (before v8) had an API that mapped less directly to the gRPC Ledger API.
# But with the HTTP JSON API, many common ledger methods now have much more direct translations that
# still manage to adhere quite closely to dazl's historical behavior.
#
# References:
#  * https://github.com/digital-asset/daml/blob/main/ledger-service/http-json/src/main/scala/com/digitalasset/http/CommandService.scala
from collections.abc import Mapping as _Mapping
import sys
from typing import Any, Optional, Sequence

from google.protobuf.json_format import MessageToDict

from ..._gen.com.daml.ledger.api import v1 as lapipb
from ..._gen.com.daml.ledger.api.v1 import admin as lapiadminpb
from ...damlast.daml_lf_1 import (
    DefTemplate,
    DottedName,
    ModuleRef,
    PackageRef,
    TemplateChoice,
    Type,
    TypeConName,
)
from ...damlast.daml_types import ContractId as ContractIdType, con
from ...damlast.lookup import MultiPackageLookup
from ...damlast.protocols import SymbolLookup, TemplateOrInterface
from ...damlast.util import module_local_name, module_name, package_local_name, package_ref
from ...ledger.aio import PackageService
from ...prim import ContractData, ContractId, Party
from ...values import Context
from ...values.protobuf import ProtobufDecoder, ProtobufEncoder, set_value
from .._offsets import End
from ..aio import PackageLoader
from ..api_types import (
    ActAs,
    Admin,
    ArchiveEvent,
    Command,
    CreateAndExerciseCommand,
    CreateCommand,
    CreateEvent,
    ExerciseByKeyCommand,
    ExerciseCommand,
    ExerciseResponse,
    IdentityProviderAdmin,
    InterfaceView,
    MeteringReport,
    MeteringReportApplication,
    MeteringReportRequest,
    PartyInfo,
    ReadAs,
    Right,
    User,
    Version,
    VersionFeatures,
    VersionUserManagementFeature,
    _Admin,
    _IdentityProviderAdmin,
)
from ..auth import TokenOrTokenProvider
from ..pkgcache import SHARED_PACKAGE_DATABASE

if sys.version_info >= (3, 11):
    from typing import assert_never
else:
    from typing_extensions import assert_never

__all__ = ["Codec"]


class Codec:
    """
    Contains methods for converting to/from Protobuf Ledger API types.

    Some encode/decode methods require package information to be available, which is why a
    connection must be supplied in order to use the codec.

    By default, the package database is _globally_ shared; this is safe to do because we make the
    same assumption that the remote gRPC Ledger API implementation makes: that package IDs uniquely
    identify package contents.
    """

    def __init__(
        self, conn: Optional[PackageService] = None, lookup: Optional[MultiPackageLookup] = None
    ):
        self.conn = conn
        self._lookup = lookup or SHARED_PACKAGE_DATABASE
        self._loader = PackageLoader(self._lookup, conn)
        self._encode_context = Context(ProtobufEncoder(), self._lookup)
        self._decode_context = Context(ProtobufDecoder(), self._lookup)

    @property
    def lookup(self) -> SymbolLookup:
        return self._lookup

    async def preload(self, contents) -> None:
        await self._loader.preload(contents)

    async def encode_command(
        self, cmd: Command, /, *, token: Optional[TokenOrTokenProvider] = None
    ) -> lapipb.Command:
        match cmd:
            case CreateCommand(template_id, payload):
                return lapipb.Command(
                    create=await self.encode_create_command(template_id, payload, token=token)
                )
            case ExerciseCommand(contract_id, choice, argument, choice_interface_id):
                return lapipb.Command(
                    exercise=await self.encode_exercise_command(
                        contract_id,
                        choice,
                        argument,
                        choice_interface_id=choice_interface_id,
                        token=token,
                    )
                )
            case ExerciseByKeyCommand(template_id, key, choice, argument):
                return lapipb.Command(
                    exerciseByKey=await self.encode_exercise_by_key_command(
                        template_id, choice, key, argument, token=token
                    )
                )
            case CreateAndExerciseCommand(template_id, payload, choice, argument):
                return lapipb.Command(
                    createAndExercise=await self.encode_create_and_exercise_command(
                        template_id, payload, choice, argument, token=token
                    )
                )
            case _:
                assert_never(cmd)

    async def encode_create_command(
        self,
        template_id: str | TypeConName,
        payload: ContractData,
        /,
        *,
        token: Optional[TokenOrTokenProvider] = None,
    ) -> lapipb.CreateCommand:
        symbols = await self._loader.search(template_id, token=token)
        if str(template_id).startswith("#"):
            item_type = symbols.templates.single().package_name_ref
            if item_type is None:
                raise ValueError(
                    "passed in a smart-contract-upgrade compatible name, but did not find a corresponding package name"
                )
        else:
            item_type = symbols.templates.single().package_id_ref

        _, value = await self.encode_value(con(item_type), payload, token=token)
        return lapipb.CreateCommand(
            template_id=self.encode_identifier(item_type), create_arguments=value
        )

    async def encode_exercise_command(
        self,
        contract_id: ContractId,
        choice_name: str,
        argument: Optional[Any] = None,
        /,
        *,
        choice_interface_id: None | str | TypeConName = None,
        token: Optional[TokenOrTokenProvider] = None,
    ) -> lapipb.ExerciseCommand:
        if choice_interface_id is not None:
            contract_id = contract_id.to_interface(choice_interface_id)

        item_type, choice = await self._look_up_choice(
            contract_id.value_type, choice_name, token=token
        )

        cmd_pb = lapipb.ExerciseCommand(
            # template_id here actually means either template_id or interface_id
            # (see https://github.com/digital-asset/daml/issues/14747)
            template_id=self.encode_identifier(item_type),
            contract_id=contract_id.value,
            choice=choice_name,
        )
        value_field, value_pb = await self.encode_value(
            choice.arg_binder.type, argument, token=token
        )
        set_value(cmd_pb.choice_argument, value_field, value_pb)

        return cmd_pb

    async def encode_create_and_exercise_command(
        self,
        template_id: str | TypeConName,
        payload: ContractData,
        choice_name: str,
        argument: Optional[Any] = None,
        /,
        *,
        token: Optional[TokenOrTokenProvider] = None,
    ) -> lapipb.CreateAndExerciseCommand:
        item_type, choice = await self._look_up_choice(template_id, choice_name, token=token)

        payload_field, payload_pb = await self.encode_value(con(item_type), payload, token=token)
        if payload_field != "record":
            raise ValueError("unexpected non-record type when constructing payload")
        argument_field, argument_pb = await self.encode_value(
            choice.arg_binder.type, argument, token=token
        )
        cmd_pb = lapipb.CreateAndExerciseCommand(
            create_arguments=payload_pb,
            template_id=self.encode_identifier(item_type),
            choice=choice_name,
        )
        set_value(cmd_pb.choice_argument, argument_field, argument_pb)

        return cmd_pb

    async def encode_exercise_by_key_command(
        self,
        template_id: str | TypeConName,
        choice_name: str,
        key: Any,
        argument: Optional[ContractData] = None,
        /,
        *,
        token: Optional[TokenOrTokenProvider] = None,
    ) -> lapipb.ExerciseByKeyCommand:
        item_type, template, choice = await self._look_up_template_choice(
            template_id, choice_name, token=token
        )
        if template.key is None:
            raise ValueError(
                f"cannot encode ExerciseByKeyCommand; template {template_id} does not have a contract key defined"
            )

        cmd_pb = lapipb.ExerciseByKeyCommand(
            template_id=self.encode_identifier(item_type),
            choice=choice_name,
        )
        key_field, key_pb = await self.encode_value(template.key.type, key, token=token)
        value_field, value_pb = await self.encode_value(
            choice.arg_binder.type, argument, token=token
        )
        set_value(cmd_pb.contract_key, key_field, key_pb)
        set_value(cmd_pb.choice_argument, value_field, value_pb)

        return cmd_pb

    async def encode_filters(
        self,
        template_or_interface_ids: Sequence[TypeConName],
        /,
        *,
        token: Optional[TokenOrTokenProvider] = None,
    ) -> lapipb.Filters:
        # Search for a reference to the "wildcard" template; if any of the requested
        # template_or_interface_ids is "*", then return results for all templates.
        # We do this first because resolving template IDs otherwise requires do_with_retry,
        # which can be expensive.
        if not template_or_interface_ids or any(
            package_ref(t) == "*" and package_local_name(t) == "*"
            for t in template_or_interface_ids
        ):
            # if any of the keys references the "wildcard" template, (or no values were supplied)
            # then this means we need to fetch values for all templates
            return lapipb.Filters()

        # No wildcard template IDs, so inspect and resolve all template references to concrete
        # template or interface IDs
        templates = list[TypeConName]()
        interfaces = list[TypeConName]()
        for template_or_interface_id in template_or_interface_ids:
            pkg_ref = package_ref(template_or_interface_id)
            local_name = package_local_name(template_or_interface_id)

            matches = await self._loader.search(template_or_interface_id, token=token)
            if pkg_ref.startswith("#"):
                # if the user asked for SCU names, continue to use that in the constructed query
                templates.extend(matches.templates.package_name_refs())
                interfaces.extend(matches.interfaces.package_name_refs())
            else:
                # for everything else, use explicit package ID references
                templates.extend(matches.templates.package_id_refs())
                interfaces.extend(matches.interfaces.package_id_refs())

        return lapipb.Filters(
            inclusive=lapipb.InclusiveFilters(
                template_ids=[self.encode_identifier(i) for i in templates],
                interface_filters=[
                    lapipb.InterfaceFilter(
                        interface_id=self.encode_identifier(i), include_interface_view=True
                    )
                    for i in interfaces
                ],
            )
        )

    async def encode_value(
        self, item_type: Type, obj: Any, /, *, token: Optional[TokenOrTokenProvider] = None
    ) -> tuple[str, Optional[Any]]:
        """
        Convert a dazl/Python value to its Protobuf equivalent.
        """
        return await self._loader.do_with_retry(
            lambda: self._encode_context.convert(item_type, obj),
            token=token,
        )

    @staticmethod
    def encode_identifier(name: TypeConName, /) -> lapipb.Identifier:
        return lapipb.Identifier(
            package_id=package_ref(name),
            module_name=str(module_name(name)),
            entity_name=module_local_name(name),
        )

    @staticmethod
    def encode_user(user: User, /) -> lapiadminpb.User:
        return lapiadminpb.User(
            id=user.id,
            primary_party=user.primary_party,
            metadata=lapiadminpb.ObjectMeta(
                resource_version=user.resource_version, annotations=user.annotations
            ),
        )

    @staticmethod
    def encode_right(right: Right, /) -> lapiadminpb.Right:
        match right:
            case _Admin():
                return lapiadminpb.Right(participant_admin=lapiadminpb.Right.ParticipantAdmin())
            case _IdentityProviderAdmin():
                return lapiadminpb.Right(
                    identity_provider_admin=lapiadminpb.Right.IdentityProviderAdmin()
                )
            case ReadAs(party):
                return lapiadminpb.Right(can_read_as=lapiadminpb.Right.CanReadAs(party=party))
            case ActAs(party):
                return lapiadminpb.Right(can_act_as=lapiadminpb.Right.CanActAs(party=party))
            case _:
                assert_never(right)

    @staticmethod
    def encode_begin_offset(offset: Optional[str], /) -> lapipb.LedgerOffset:
        if offset is None:
            return lapipb.LedgerOffset(boundary=lapipb.LedgerOffset.LEDGER_BEGIN)
        else:
            return lapipb.LedgerOffset(absolute=offset)

    @staticmethod
    def encode_end_offset(offset: Optional[str | End], /) -> Optional[lapipb.LedgerOffset]:
        if offset is None:
            # there is no ending offset (the stream will never naturally terminate)
            return None
        elif isinstance(offset, End):
            # the offset goes up until the current end of the ledger
            return lapipb.LedgerOffset(boundary=lapipb.LedgerOffset.LEDGER_END)
        else:
            # the offset is absolute
            return lapipb.LedgerOffset(absolute=offset)

    async def decode_created_event(
        self, event: lapipb.CreatedEvent, /, *, token: Optional[TokenOrTokenProvider] = None
    ) -> CreateEvent:
        cid = self.decode_contract_id(event)
        cdata = await self.decode_value(con(cid.value_type), event.create_arguments, token=token)
        if not isinstance(cdata, _Mapping):
            raise ValueError(
                f"expected create_arguments to result in a dict, but got {cdata!r} instead"
            )

        lookup = self._lookup.search(cid.value_type)
        template = next(iter(lookup.templates.values()))
        key = None
        if template is not None and template.key is not None:
            key = await self.decode_value(template.key.type, event.contract_key, token=token)

        return CreateEvent(
            cid,
            cdata,
            tuple(Party(p) for p in event.signatories),
            tuple(Party(p) for p in event.observers),
            event.agreement_text.value,
            key,
            created_event_blob=event.created_event_blob or None,
            interface_views=[
                await self.decode_interface_view(v, token=token) for v in event.interface_views
            ],
        )

    async def decode_archived_event(self, event: lapipb.ArchivedEvent, /) -> ArchiveEvent:
        cid = self.decode_contract_id(event)
        return ArchiveEvent(cid)

    async def decode_exercise_response(
        self, tree: lapipb.TransactionTree, /, *, token: Optional[TokenOrTokenProvider] = None
    ) -> ExerciseResponse:
        """
        Convert a Protobuf TransactionTree response to an ExerciseResponse. The TransactionTree is
        expected to only contain a single exercise node at the root level.
        """
        from ... import LOG

        found_choice = None
        result = None
        cid = None

        events = list[CreateEvent | ArchiveEvent]()
        for event_id in tree.root_event_ids:
            event_pb = tree.events_by_id[event_id]
            event_pb_type = event_pb.WhichOneof("kind")

            match event_pb_type:
                case "created":
                    events.append(await self.decode_created_event(event_pb.created, token=token))
                case "exercised":
                    # Find the "first" exercised node and grab its result value
                    if cid is None:
                        cid = self.decode_contract_id(event_pb.exercised)

                        template_or_interface: TemplateOrInterface
                        if event_pb.exercised.interface_id.entity_name:
                            symbols = self._lookup.search(
                                Codec.decode_identifier(event_pb.exercised.interface_id)
                            )
                            template_or_interface = symbols.interfaces.single().object
                        else:
                            symbols = self._lookup.search(cid.value_type)
                            template_or_interface = symbols.templates.single().object

                        if found_choice is None:
                            for choice in template_or_interface.choices:
                                if choice.name == event_pb.exercised.choice:
                                    found_choice = choice
                                    break
                            if found_choice is not None:
                                result = await self.decode_value(
                                    found_choice.ret_type,
                                    event_pb.exercised.exercise_result,
                                    token=token,
                                )
                            else:
                                LOG.error(
                                    "Received an exercise node that referred to a choice that doesn't exist!"
                                )

                    events.extend(
                        await self._decode_exercised_child_events(tree, [event_id], token=token)
                    )
                case _:
                    LOG.warning("Received an unknown event type: %s", event_pb_type)

        return ExerciseResponse(result, events)

    async def _decode_exercised_child_events(
        self,
        tree: lapipb.TransactionTree,
        event_ids: Sequence[str],
        /,
        *,
        token: Optional[TokenOrTokenProvider] = None,
    ) -> Sequence[CreateEvent | ArchiveEvent]:
        from ... import LOG

        events = list[CreateEvent | ArchiveEvent]()
        for event_id in event_ids:
            event_pb = tree.events_by_id[event_id]
            event_pb_type = event_pb.WhichOneof("kind")
            if event_pb_type == "created":
                events.append(await self.decode_created_event(event_pb.created, token=token))
            elif event_pb_type == "exercised":
                if event_pb.exercised.consuming:
                    events.append(ArchiveEvent(self.decode_contract_id(event_pb.exercised)))
                events.extend(
                    await self._decode_exercised_child_events(
                        tree, event_pb.exercised.child_event_ids, token=token
                    )
                )
            else:
                LOG.warning("Received an unknown event type: %s", event_pb_type)
        return events

    async def decode_interface_view(
        self, pb: lapipb.InterfaceView, /, *, token: Optional[TokenOrTokenProvider] = None
    ) -> InterfaceView:
        vt = Codec.decode_identifier(pb.interface_id)

        symbols = self._lookup.search(vt)
        interface = symbols.interfaces.single().object
        view_value = await self.decode_value(interface.view, pb.view_value, token=token)
        return InterfaceView(vt, view_value)

    async def decode_value(
        self, item_type: Type, obj: Any, /, *, token: Optional[TokenOrTokenProvider] = None
    ) -> Optional[Any]:
        """
        Convert a Protobuf Ledger API value to its dazl/Python equivalent.
        """
        return await self._loader.do_with_retry(
            lambda: self._decode_context.convert(item_type, obj), token=token
        )

    def decode_contract_id(
        self, event: lapipb.CreatedEvent | lapipb.ExercisedEvent | lapipb.ArchivedEvent, /
    ) -> ContractId:
        vt = Codec.decode_identifier(event.template_id)
        return self._decode_context.convert(ContractIdType(con(vt)), event.contract_id)

    @staticmethod
    def decode_identifier(identifier: lapipb.Identifier, /) -> TypeConName:
        return TypeConName(
            ModuleRef(
                PackageRef(identifier.package_id), DottedName(identifier.module_name.split("."))
            ),
            DottedName(identifier.entity_name.split(".")).segments,
        )

    @staticmethod
    def decode_user(user: lapiadminpb.User, /) -> User:
        return User(
            id=user.id,
            primary_party=Party(user.primary_party),
            resource_version=user.metadata.resource_version,
            annotations=dict(user.metadata.annotations),
        )

    @staticmethod
    def decode_right(right: lapiadminpb.Right, /) -> Right:
        kind = right.WhichOneof("kind")
        match kind:
            case "participant_admin":
                return Admin
            case "identity_provider_admin":
                return IdentityProviderAdmin
            case "can_read_as":
                return ReadAs(Party(right.can_read_as.party))
            case "can_act_as":
                return ActAs(Party(right.can_act_as.party))
            case _:
                raise ValueError(f"unexpected kind of right: {kind}")

    @staticmethod
    def decode_party_info(party_details: lapiadminpb.PartyDetails, /) -> PartyInfo:
        return PartyInfo(
            Party(party_details.party), party_details.display_name, party_details.is_local
        )

    @staticmethod
    def decode_version(obj: lapipb.GetLedgerApiVersionResponse, /) -> Version:
        return Version(
            version=obj.version,
            features=VersionFeatures(
                user_management=VersionUserManagementFeature(
                    supported=obj.features.user_management.supported,
                    max_rights_per_user=obj.features.user_management.max_rights_per_user,
                    max_users_page_size=obj.features.user_management.max_users_page_size,
                ),
            ),
        )

    @staticmethod
    def decode_get_metering_report_response(
        obj: lapiadminpb.GetMeteringReportResponse, /
    ) -> MeteringReport:
        # unfortunately with a JSON-based format, we lose a considerable degree
        # of type safety, and this (rightfully) makes mypy complain loudly
        report_json = MessageToDict(obj.metering_report_json)

        return MeteringReport(
            request=MeteringReportRequest(
                report_json.get("application"),  # type: ignore
                report_json.get("from"),  # type: ignore
                report_json.get("to"),  # type: ignore
            ),
            participant=report_json["participant"],  # type: ignore
            final=report_json["final"],  # type: ignore
            applications=[
                MeteringReportApplication(
                    o["application"],  # type: ignore
                    int(o["events"]),  # type: ignore
                )
                for o in report_json["applications"]
            ],
        )

    async def _look_up_choice(
        self,
        template_or_interface_id: Any,
        choice_name: str,
        /,
        *,
        token: Optional[TokenOrTokenProvider] = None,
    ) -> tuple[TypeConName, TemplateChoice]:
        result = await self._loader.search(template_or_interface_id, token=token)

        for template_id, template in result.templates.items():
            for choice in template.choices:
                if choice.name == choice_name:
                    return template_id, choice

        for interface_id, interface in result.interfaces.items():
            for choice in interface.choices:
                if choice.name == choice_name:
                    return interface_id, choice

        raise ValueError(
            f"template/interface {template_or_interface_id} has no choice named {choice_name}"
        )

    async def _look_up_template_choice(
        self, template_id: Any, choice_name: str, /, *, token: Optional[TokenOrTokenProvider] = None
    ) -> tuple[TypeConName, DefTemplate, TemplateChoice]:
        result = await self._loader.search(template_id, token=token)

        for template_id, template in result.templates.items():
            for choice in template.choices:
                if choice.name == choice_name:
                    return template_id, template, choice

        raise ValueError(f"template {template_id} has no choice named {choice_name}")



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.map_int_tree_event import MapIntTreeEvent
    from ..models.trace_context import TraceContext


T = TypeVar("T", bound="JsTransactionTree")


@_attrs_define
class JsTransactionTree:
    """Provided for backwards compatibility, it will be removed in the Canton version 3.5.0.
    Complete view of an on-ledger transaction.

        Attributes:
            update_id (str): Assigned by the server. Useful for correlating logs.
                Must be a valid LedgerString (as described in ``value.proto``).
                Required
            command_id (str): The ID of the command which resulted in this transaction. Missing for everyone except the
                submitting party.
                Must be a valid LedgerString (as described in ``value.proto``).
                Optional
            workflow_id (str): The workflow ID used in command submission. Only set if the ``workflow_id`` for the command
                was set.
                Must be a valid LedgerString (as described in ``value.proto``).
                Optional
            offset (int): The absolute offset. The details of this field are described in ``community/ledger-
                api/README.md``.
                Required, it is a valid absolute offset (positive integer).
            events_by_id (MapIntTreeEvent):
            synchronizer_id (str): A valid synchronizer id.
                Identifies the synchronizer that synchronized the transaction.
                Required
            record_time (str): The time at which the transaction was recorded. The record time refers to the synchronizer
                which synchronized the transaction.
                Required
            effective_at (str | Unset): Ledger effective time.
                Required
            trace_context (TraceContext | Unset):
    """

    update_id: str
    command_id: str
    workflow_id: str
    offset: int
    events_by_id: MapIntTreeEvent
    synchronizer_id: str
    record_time: str
    effective_at: str | Unset = UNSET
    trace_context: TraceContext | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        update_id = self.update_id

        command_id = self.command_id

        workflow_id = self.workflow_id

        offset = self.offset

        events_by_id = self.events_by_id.to_dict()

        synchronizer_id = self.synchronizer_id

        record_time = self.record_time

        effective_at = self.effective_at

        trace_context: dict[str, Any] | Unset = UNSET
        if not isinstance(self.trace_context, Unset):
            trace_context = self.trace_context.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "updateId": update_id,
                "commandId": command_id,
                "workflowId": workflow_id,
                "offset": offset,
                "eventsById": events_by_id,
                "synchronizerId": synchronizer_id,
                "recordTime": record_time,
            }
        )
        if effective_at is not UNSET:
            field_dict["effectiveAt"] = effective_at
        if trace_context is not UNSET:
            field_dict["traceContext"] = trace_context

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.map_int_tree_event import MapIntTreeEvent
        from ..models.trace_context import TraceContext

        d = dict(src_dict)
        update_id = d.pop("updateId")

        command_id = d.pop("commandId")

        workflow_id = d.pop("workflowId")

        offset = d.pop("offset")

        events_by_id = MapIntTreeEvent.from_dict(d.pop("eventsById"))

        synchronizer_id = d.pop("synchronizerId")

        record_time = d.pop("recordTime")

        effective_at = d.pop("effectiveAt", UNSET)

        _trace_context = d.pop("traceContext", UNSET)
        trace_context: TraceContext | Unset
        if isinstance(_trace_context, Unset):
            trace_context = UNSET
        else:
            trace_context = TraceContext.from_dict(_trace_context)

        js_transaction_tree = cls(
            update_id=update_id,
            command_id=command_id,
            workflow_id=workflow_id,
            offset=offset,
            events_by_id=events_by_id,
            synchronizer_id=synchronizer_id,
            record_time=record_time,
            effective_at=effective_at,
            trace_context=trace_context,
        )

        js_transaction_tree.additional_properties = d
        return js_transaction_tree

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .vault_service_pb2 import DeleteKeyPairRequest, DeleteKeyPairResponse, ExportKeyPairRequest, ExportKeyPairResponse, GenerateEncryptionKeyRequest, GenerateEncryptionKeyResponse, GenerateSigningKeyRequest, GenerateSigningKeyResponse, GetWrapperKeyIdRequest, GetWrapperKeyIdResponse, ImportKeyPairRequest, ImportKeyPairResponse, ImportPublicKeyRequest, ImportPublicKeyResponse, ListMyKeysRequest, ListMyKeysResponse, ListPublicKeysRequest, ListPublicKeysResponse, RegisterKmsEncryptionKeyRequest, RegisterKmsEncryptionKeyResponse, RegisterKmsSigningKeyRequest, RegisterKmsSigningKeyResponse, RotateWrapperKeyRequest, RotateWrapperKeyResponse

__all__ = [
    "VaultServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class VaultServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _VaultServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _VaultServiceAsyncStub: ...  # type: ignore
    def ListMyKeys(self, __1: ListMyKeysRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListMyKeysResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListMyKeysResponse]: ...
    def GenerateSigningKey(self, __1: GenerateSigningKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GenerateSigningKeyResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GenerateSigningKeyResponse]: ...
    def GenerateEncryptionKey(self, __1: GenerateEncryptionKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GenerateEncryptionKeyResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GenerateEncryptionKeyResponse]: ...
    def RegisterKmsEncryptionKey(self, __1: RegisterKmsEncryptionKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RegisterKmsEncryptionKeyResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, RegisterKmsEncryptionKeyResponse]: ...
    def RegisterKmsSigningKey(self, __1: RegisterKmsSigningKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RegisterKmsSigningKeyResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, RegisterKmsSigningKeyResponse]: ...
    def ImportPublicKey(self, __1: ImportPublicKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportPublicKeyResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ImportPublicKeyResponse]: ...
    def ListPublicKeys(self, __1: ListPublicKeysRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPublicKeysResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListPublicKeysResponse]: ...
    def RotateWrapperKey(self, __1: RotateWrapperKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RotateWrapperKeyResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, RotateWrapperKeyResponse]: ...
    def GetWrapperKeyId(self, __1: GetWrapperKeyIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetWrapperKeyIdResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetWrapperKeyIdResponse]: ...
    def ExportKeyPair(self, __1: ExportKeyPairRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ExportKeyPairResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ExportKeyPairResponse]: ...
    def ImportKeyPair(self, __1: ImportKeyPairRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportKeyPairResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ImportKeyPairResponse]: ...
    def DeleteKeyPair(self, __1: DeleteKeyPairRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> DeleteKeyPairResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, DeleteKeyPairResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _VaultServiceBlockingStub(VaultServiceStub):
    def ListMyKeys(self, __1: ListMyKeysRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListMyKeysResponse: ...
    def GenerateSigningKey(self, __1: GenerateSigningKeyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GenerateSigningKeyResponse: ...
    def GenerateEncryptionKey(self, __1: GenerateEncryptionKeyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GenerateEncryptionKeyResponse: ...
    def RegisterKmsEncryptionKey(self, __1: RegisterKmsEncryptionKeyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RegisterKmsEncryptionKeyResponse: ...
    def RegisterKmsSigningKey(self, __1: RegisterKmsSigningKeyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RegisterKmsSigningKeyResponse: ...
    def ImportPublicKey(self, __1: ImportPublicKeyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportPublicKeyResponse: ...
    def ListPublicKeys(self, __1: ListPublicKeysRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPublicKeysResponse: ...
    def RotateWrapperKey(self, __1: RotateWrapperKeyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RotateWrapperKeyResponse: ...
    def GetWrapperKeyId(self, __1: GetWrapperKeyIdRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetWrapperKeyIdResponse: ...
    def ExportKeyPair(self, __1: ExportKeyPairRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ExportKeyPairResponse: ...
    def ImportKeyPair(self, __1: ImportKeyPairRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportKeyPairResponse: ...
    def DeleteKeyPair(self, __1: DeleteKeyPairRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> DeleteKeyPairResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _VaultServiceAsyncStub(VaultServiceStub):
    def ListMyKeys(self, __1: ListMyKeysRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListMyKeysResponse]: ...  # type: ignore
    def GenerateSigningKey(self, __1: GenerateSigningKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GenerateSigningKeyResponse]: ...  # type: ignore
    def GenerateEncryptionKey(self, __1: GenerateEncryptionKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GenerateEncryptionKeyResponse]: ...  # type: ignore
    def RegisterKmsEncryptionKey(self, __1: RegisterKmsEncryptionKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, RegisterKmsEncryptionKeyResponse]: ...  # type: ignore
    def RegisterKmsSigningKey(self, __1: RegisterKmsSigningKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, RegisterKmsSigningKeyResponse]: ...  # type: ignore
    def ImportPublicKey(self, __1: ImportPublicKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ImportPublicKeyResponse]: ...  # type: ignore
    def ListPublicKeys(self, __1: ListPublicKeysRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPublicKeysResponse]: ...  # type: ignore
    def RotateWrapperKey(self, __1: RotateWrapperKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, RotateWrapperKeyResponse]: ...  # type: ignore
    def GetWrapperKeyId(self, __1: GetWrapperKeyIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetWrapperKeyIdResponse]: ...  # type: ignore
    def ExportKeyPair(self, __1: ExportKeyPairRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ExportKeyPairResponse]: ...  # type: ignore
    def ImportKeyPair(self, __1: ImportKeyPairRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ImportKeyPairResponse]: ...  # type: ignore
    def DeleteKeyPair(self, __1: DeleteKeyPairRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, DeleteKeyPairResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/synchronizer_parameters.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/protocol/v30/synchronizer_parameters.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import traffic_control_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_traffic__control__parameters__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBcom/digitalasset/canton/protocol/v30/synchronizer_parameters.proto\x12$com.digitalasset.canton.protocol.v30\x1a\x45\x63om/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x1a\x1egoogle/protobuf/duration.proto\"\x97\x01\n\x1b\x41\x63sCommitmentsCatchUpConfig\x12\x32\n\x15\x63\x61tchup_interval_skip\x18\x01 \x01(\rR\x13\x63\x61tchupIntervalSkip\x12\x44\n\x1fnr_intervals_to_trigger_catchup\x18\x02 \x01(\rR\x1bnrIntervalsToTriggerCatchup\"p\n\x1dParticipantSynchronizerLimits\x12\x43\n\x1e\x63onfirmation_requests_max_rate\x18\x01 \x01(\rR\x1b\x63onfirmationRequestsMaxRateJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"\xd7\n\n\x1d\x44ynamicSynchronizerParameters\x12]\n\x1d\x63onfirmation_response_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1b\x63onfirmationResponseTimeout\x12U\n\x19mediator_reaction_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x17mediatorReactionTimeout\x12_\n\x1e\x61ssignment_exclusivity_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1c\x61ssignmentExclusivityTimeout\x12\x63\n!ledger_time_record_time_tolerance\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1dledgerTimeRecordTimeTolerance\x12R\n\x17reconciliation_interval\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x16reconciliationInterval\x12_\n\x1emediator_deduplication_timeout\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1cmediatorDeduplicationTimeout\x12(\n\x10max_request_size\x18\x08 \x01(\rR\x0emaxRequestSize\x12r\n\x16onboarding_restriction\x18\t \x01(\x0e\x32;.com.digitalasset.canton.protocol.v30.OnboardingRestrictionR\x15onboardingRestriction\x12\x8b\x01\n\x1fparticipant_synchronizer_limits\x18\r \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.ParticipantSynchronizerLimitsR\x1dparticipantSynchronizerLimits\x12n\n&sequencer_aggregate_submission_timeout\x18\x0f \x01(\x0b\x32\x19.google.protobuf.DurationR#sequencerAggregateSubmissionTimeout\x12g\n\x0ftraffic_control\x18\x10 \x01(\x0b\x32>.com.digitalasset.canton.protocol.v30.TrafficControlParametersR\x0etrafficControl\x12y\n\x17\x61\x63s_commitments_catchup\x18\x11 \x01(\x0b\x32\x41.com.digitalasset.canton.protocol.v30.AcsCommitmentsCatchUpConfigR\x15\x61\x63sCommitmentsCatchup\x12m\n&preparation_time_record_time_tolerance\x18\x12 \x01(\x0b\x32\x19.google.protobuf.DurationR\"preparationTimeRecordTimeToleranceJ\x04\x08\x04\x10\x05J\x04\x08\x0b\x10\x0cJ\x04\x08\x0c\x10\rJ\x04\x08\x0e\x10\x0f*\xf7\x01\n\x15OnboardingRestriction\x12&\n\"ONBOARDING_RESTRICTION_UNSPECIFIED\x10\x00\x12,\n(ONBOARDING_RESTRICTION_UNRESTRICTED_OPEN\x10\x01\x12.\n*ONBOARDING_RESTRICTION_UNRESTRICTED_LOCKED\x10\x02\x12*\n&ONBOARDING_RESTRICTION_RESTRICTED_OPEN\x10\x03\x12,\n(ONBOARDING_RESTRICTION_RESTRICTED_LOCKED\x10\x04\x42UZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.synchronizer_parameters_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_ONBOARDINGRESTRICTION']._serialized_start=1850
  _globals['_ONBOARDINGRESTRICTION']._serialized_end=2097
  _globals['_ACSCOMMITMENTSCATCHUPCONFIG']._serialized_start=212
  _globals['_ACSCOMMITMENTSCATCHUPCONFIG']._serialized_end=363
  _globals['_PARTICIPANTSYNCHRONIZERLIMITS']._serialized_start=365
  _globals['_PARTICIPANTSYNCHRONIZERLIMITS']._serialized_end=477
  _globals['_DYNAMICSYNCHRONIZERPARAMETERS']._serialized_start=480
  _globals['_DYNAMICSYNCHRONIZERPARAMETERS']._serialized_end=1847
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/protocol/v30/party_replication.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/participant/protocol/v30/party_replication.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....admin.participant.v30 import active_contract_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_active__contract__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHcom/digitalasset/canton/participant/protocol/v30/party_replication.proto\x12\x30\x63om.digitalasset.canton.participant.protocol.v30\x1a\x43\x63om/digitalasset/canton/admin/participant/v30/active_contract.proto\"\x82\x04\n(PartyReplicationTargetParticipantMessage\x12\x87\x01\n\ninitialize\x18\x01 \x01(\x0b\x32\x65.com.digitalasset.canton.participant.protocol.v30.PartyReplicationTargetParticipantMessage.InitializeH\x00R\ninitialize\x12\x8d\x01\n\x0esend_acs_up_to\x18\x02 \x01(\x0b\x32\x66.com.digitalasset.canton.participant.protocol.v30.PartyReplicationTargetParticipantMessage.SendAcsUpToH\x00R\x0bsendAcsUpTo\x1aY\n\nInitialize\x12K\n\"initial_contract_ordinal_inclusive\x18\x01 \x01(\rR\x1finitialContractOrdinalInclusive\x1aR\n\x0bSendAcsUpTo\x12\x43\n\x1emax_contract_ordinal_inclusive\x18\x01 \x01(\rR\x1bmaxContractOrdinalInclusiveB\r\n\x0binstruction\"\xbf\x03\n(PartyReplicationSourceParticipantMessage\x12\x82\x01\n\tacs_batch\x18\x01 \x01(\x0b\x32\x63.com.digitalasset.canton.participant.protocol.v30.PartyReplicationSourceParticipantMessage.AcsBatchH\x00R\x08\x61\x63sBatch\x12\x83\x01\n\nend_of_acs\x18\x02 \x01(\x0b\x32\x63.com.digitalasset.canton.participant.protocol.v30.PartyReplicationSourceParticipantMessage.EndOfACSH\x00R\x08\x65ndOfAcs\x1aj\n\x08\x41\x63sBatch\x12^\n\tcontracts\x18\x01 \x03(\x0b\x32@.com.digitalasset.canton.admin.participant.v30.ActiveContractOldR\tcontracts\x1a\n\n\x08\x45ndOfACSB\x10\n\x0e\x64\x61ta_or_statusBaZ_github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.protocol.v30.party_replication_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z_github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v30'
  _globals['_PARTYREPLICATIONTARGETPARTICIPANTMESSAGE']._serialized_start=196
  _globals['_PARTYREPLICATIONTARGETPARTICIPANTMESSAGE']._serialized_end=710
  _globals['_PARTYREPLICATIONTARGETPARTICIPANTMESSAGE_INITIALIZE']._serialized_start=522
  _globals['_PARTYREPLICATIONTARGETPARTICIPANTMESSAGE_INITIALIZE']._serialized_end=611
  _globals['_PARTYREPLICATIONTARGETPARTICIPANTMESSAGE_SENDACSUPTO']._serialized_start=613
  _globals['_PARTYREPLICATIONTARGETPARTICIPANTMESSAGE_SENDACSUPTO']._serialized_end=695
  _globals['_PARTYREPLICATIONSOURCEPARTICIPANTMESSAGE']._serialized_start=713
  _globals['_PARTYREPLICATIONSOURCEPARTICIPANTMESSAGE']._serialized_end=1160
  _globals['_PARTYREPLICATIONSOURCEPARTICIPANTMESSAGE_ACSBATCH']._serialized_start=1024
  _globals['_PARTYREPLICATIONSOURCEPARTICIPANTMESSAGE_ACSBATCH']._serialized_end=1130
  _globals['_PARTYREPLICATIONSOURCEPARTICIPANTMESSAGE_ENDOFACS']._serialized_start=1132
  _globals['_PARTYREPLICATIONSOURCEPARTICIPANTMESSAGE_ENDOFACS']._serialized_end=1142
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/api/v30/sequencer_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/sequencer/api/v30/sequencer_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import traffic_control_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_traffic__control__parameters__pb2
from ....topology.admin.v30 import common_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_common__pb2
from ....v30 import trace_context_pb2 as com_dot_digitalasset_dot_canton_dot_v30_dot_trace__context__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAcom/digitalasset/canton/sequencer/api/v30/sequencer_service.proto\x12)com.digitalasset.canton.sequencer.api.v30\x1a\x45\x63om/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x1a\x37\x63om/digitalasset/canton/topology/admin/v30/common.proto\x1a/com/digitalasset/canton/v30/trace_context.proto\"N\n\x10SendAsyncRequest\x12:\n\x19signed_submission_request\x18\x01 \x01(\x0cR\x17signedSubmissionRequest\"\xfb\x01\n\x19TrafficControlErrorReason\x12`\n\x05\x65rror\x18\x01 \x01(\x0b\x32J.com.digitalasset.canton.sequencer.api.v30.TrafficControlErrorReason.ErrorR\x05\x65rror\x1a|\n\x05\x45rror\x12\x33\n\x14insufficient_traffic\x18\x01 \x01(\tH\x00R\x13insufficientTraffic\x12\x34\n\x15outdated_traffic_cost\x18\x02 \x01(\tH\x00R\x13outdatedTrafficCostB\x08\n\x06reason\"\x13\n\x11SendAsyncResponse\"^\n\x13SubscriptionRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12!\n\ttimestamp\x18\x02 \x01(\x03H\x00R\ttimestamp\x88\x01\x01\x42\x0c\n\n_timestamp\"\x9c\x01\n\x14SubscriptionResponse\x12\x34\n\x16signed_sequenced_event\x18\x01 \x01(\x0cR\x14signedSequencedEvent\x12N\n\rtrace_context\x18\x02 \x01(\x0b\x32).com.digitalasset.canton.v30.TraceContextR\x0ctraceContext\"J\n\x12\x41\x63knowledgeRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\"\x15\n\x13\x41\x63knowledgeResponse\"X\n\x18\x41\x63knowledgeSignedRequest\x12<\n\x1asigned_acknowledge_request\x18\x01 \x01(\x0cR\x18signedAcknowledgeRequest\"\x1b\n\x19\x41\x63knowledgeSignedResponse\"=\n#DownloadTopologyStateForInitRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\"\x9d\x01\n$DownloadTopologyStateForInitResponse\x12u\n\x15topology_transactions\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.topology.admin.v30.TopologyTransactionsR\x14topologyTransactions\"A\n\'DownloadTopologyStateForInitHashRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\"Z\n(DownloadTopologyStateForInitHashResponse\x12.\n\x13topology_state_hash\x18\x01 \x01(\x0cR\x11topologyStateHash\"W\n\x1fGetTrafficStateForMemberRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\"{\n GetTrafficStateForMemberResponse\x12W\n\rtraffic_state\x18\x01 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v30.TrafficStateR\x0ctrafficState\"\x10\n\x0eGetTimeRequest\"b\n\x0fGetTimeResponse\x12\x36\n\x14sequencing_timestamp\x18\x01 \x01(\x03H\x00R\x13sequencingTimestamp\x88\x01\x01\x42\x17\n\x15_sequencing_timestamp2\x98\t\n\x10SequencerService\x12\x86\x01\n\tSendAsync\x12;.com.digitalasset.canton.sequencer.api.v30.SendAsyncRequest\x1a<.com.digitalasset.canton.sequencer.api.v30.SendAsyncResponse\x12\x8e\x01\n\tSubscribe\x12>.com.digitalasset.canton.sequencer.api.v30.SubscriptionRequest\x1a?.com.digitalasset.canton.sequencer.api.v30.SubscriptionResponse0\x01\x12\x9e\x01\n\x11\x41\x63knowledgeSigned\x12\x43.com.digitalasset.canton.sequencer.api.v30.AcknowledgeSignedRequest\x1a\x44.com.digitalasset.canton.sequencer.api.v30.AcknowledgeSignedResponse\x12\xc1\x01\n\x1c\x44ownloadTopologyStateForInit\x12N.com.digitalasset.canton.sequencer.api.v30.DownloadTopologyStateForInitRequest\x1aO.com.digitalasset.canton.sequencer.api.v30.DownloadTopologyStateForInitResponse0\x01\x12\xcb\x01\n DownloadTopologyStateForInitHash\x12R.com.digitalasset.canton.sequencer.api.v30.DownloadTopologyStateForInitHashRequest\x1aS.com.digitalasset.canton.sequencer.api.v30.DownloadTopologyStateForInitHashResponse\x12\xb3\x01\n\x18GetTrafficStateForMember\x12J.com.digitalasset.canton.sequencer.api.v30.GetTrafficStateForMemberRequest\x1aK.com.digitalasset.canton.sequencer.api.v30.GetTrafficStateForMemberResponse\x12\x80\x01\n\x07GetTime\x12\x39.com.digitalasset.canton.sequencer.api.v30.GetTimeRequest\x1a:.com.digitalasset.canton.sequencer.api.v30.GetTimeResponseBZZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/api/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.api.v30.sequencer_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/api/v30'
  _globals['_SENDASYNCREQUEST']._serialized_start=289
  _globals['_SENDASYNCREQUEST']._serialized_end=367
  _globals['_TRAFFICCONTROLERRORREASON']._serialized_start=370
  _globals['_TRAFFICCONTROLERRORREASON']._serialized_end=621
  _globals['_TRAFFICCONTROLERRORREASON_ERROR']._serialized_start=497
  _globals['_TRAFFICCONTROLERRORREASON_ERROR']._serialized_end=621
  _globals['_SENDASYNCRESPONSE']._serialized_start=623
  _globals['_SENDASYNCRESPONSE']._serialized_end=642
  _globals['_SUBSCRIPTIONREQUEST']._serialized_start=644
  _globals['_SUBSCRIPTIONREQUEST']._serialized_end=738
  _globals['_SUBSCRIPTIONRESPONSE']._serialized_start=741
  _globals['_SUBSCRIPTIONRESPONSE']._serialized_end=897
  _globals['_ACKNOWLEDGEREQUEST']._serialized_start=899
  _globals['_ACKNOWLEDGEREQUEST']._serialized_end=973
  _globals['_ACKNOWLEDGERESPONSE']._serialized_start=975
  _globals['_ACKNOWLEDGERESPONSE']._serialized_end=996
  _globals['_ACKNOWLEDGESIGNEDREQUEST']._serialized_start=998
  _globals['_ACKNOWLEDGESIGNEDREQUEST']._serialized_end=1086
  _globals['_ACKNOWLEDGESIGNEDRESPONSE']._serialized_start=1088
  _globals['_ACKNOWLEDGESIGNEDRESPONSE']._serialized_end=1115
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITREQUEST']._serialized_start=1117
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITREQUEST']._serialized_end=1178
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITRESPONSE']._serialized_start=1181
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITRESPONSE']._serialized_end=1338
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITHASHREQUEST']._serialized_start=1340
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITHASHREQUEST']._serialized_end=1405
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITHASHRESPONSE']._serialized_start=1407
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITHASHRESPONSE']._serialized_end=1497
  _globals['_GETTRAFFICSTATEFORMEMBERREQUEST']._serialized_start=1499
  _globals['_GETTRAFFICSTATEFORMEMBERREQUEST']._serialized_end=1586
  _globals['_GETTRAFFICSTATEFORMEMBERRESPONSE']._serialized_start=1588
  _globals['_GETTRAFFICSTATEFORMEMBERRESPONSE']._serialized_end=1711
  _globals['_GETTIMEREQUEST']._serialized_start=1713
  _globals['_GETTIMEREQUEST']._serialized_end=1729
  _globals['_GETTIMERESPONSE']._serialized_start=1731
  _globals['_GETTIMERESPONSE']._serialized_end=1829
  _globals['_SEQUENCERSERVICE']._serialized_start=1832
  _globals['_SEQUENCERSERVICE']._serialized_end=3008
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.js_interface_view import JsInterfaceView


T = TypeVar("T", bound="CreatedEvent")


@_attrs_define
class CreatedEvent:
    """Records that a contract has been created, and choices may now be exercised on it.

    Attributes:
        offset (int): The offset of origin, which has contextual meaning, please see description at messages that
            include a CreatedEvent.
            Offsets are managed by the participant nodes.
            Transactions can thus NOT be assumed to have the same offsets on different participant nodes.
            Required, it is a valid absolute offset (positive integer)
        node_id (int): The position of this event in the originating transaction or reassignment.
            The origin has contextual meaning, please see description at messages that include a CreatedEvent.
            Node IDs are not necessarily equal across participants,
            as these may see different projections/parts of transactions.
            Required, must be valid node ID (non-negative integer)
        contract_id (str): The ID of the created contract.
            Must be a valid LedgerString (as described in ``value.proto``).
            Required
        template_id (str): The template of the created contract.
            The identifier uses the package-id reference format.

            Required
        created_event_blob (str): Opaque representation of contract create event payload intended for forwarding
            to an API server as a contract disclosed as part of a command
            submission.
            Optional
        created_at (str): Ledger effective time of the transaction that created the contract.
            Required
        package_name (str): The package name of the created contract.
            Required
        representative_package_id (str): A package-id present in the participant package store that typechecks the
            contract's argument.
            This may differ from the package-id of the template used to create the contract.
            For contracts created before Canton 3.4, this field matches the contract's creation package-id.

            NOTE: Experimental, server internal concept, not for client consumption. Subject to change without notice.

            Required
        acs_delta (bool): Whether this event would be part of respective ACS_DELTA shaped stream,
            and should therefore considered when tracking contract activeness on the client-side.
            Required
        contract_key (Any | Unset): The key of the created contract.
            This will be set if and only if ``template_id`` defines a contract key.
            Optional
        create_argument (Any | Unset):
        interface_views (list[JsInterfaceView] | Unset): Interface views specified in the transaction filter.
            Includes an ``InterfaceView`` for each interface for which there is a ``InterfaceFilter`` with

            - its party in the ``witness_parties`` of this event,
            - and which is implemented by the template of this event,
            - and which has ``include_interface_view`` set.

            Optional
        witness_parties (list[str] | Unset): The parties that are notified of this event. When a ``CreatedEvent``
            is returned as part of a transaction tree or ledger-effects transaction, this will include all
            the parties specified in the ``TransactionFilter`` that are witnesses  of the event
            (the stakeholders of the contract and all informees of all the ancestors
            of this create action that this participant knows about).
            If served as part of a ACS delta transaction those will
            be limited to all parties specified in the ``TransactionFilter`` that
            are stakeholders of the contract (i.e. either signatories or observers).
            If the ``CreatedEvent`` is returned as part of an AssignedEvent,
            ActiveContract or IncompleteUnassigned (so the event is related to
            an assignment or unassignment): this will include all parties of the
            ``TransactionFilter`` that are stakeholders of the contract.

            The behavior of reading create events visible to parties not hosted
            on the participant node serving the Ledger API is undefined. Concretely,
            there is neither a guarantee that the participant node will serve all their
            create events on the ACS stream, nor is there a guarantee that matching archive
            events are delivered for such create events.

            For most clients this is not a problem, as they only read events for parties
            that are hosted on the participant node. If you need to read events
            for parties that may not be hosted at all times on the participant node,
            subscribe to the ``TopologyEvent``s for that party by setting a corresponding
            ``UpdateFormat``.  Using these events, query the ACS as-of an offset where the
            party is hosted on the participant node, and ignore create events at offsets
            where the party is not hosted on the participant node.
            Required
        signatories (list[str] | Unset): The signatories for this contract as specified by the template.
            Required
        observers (list[str] | Unset): The observers for this contract as specified explicitly by the template or
            implicitly as choice controllers.
            This field never contains parties that are signatories.
            Required
    """

    offset: int
    node_id: int
    contract_id: str
    template_id: str
    created_event_blob: str
    created_at: str
    package_name: str
    representative_package_id: str
    acs_delta: bool
    contract_key: Any | Unset = UNSET
    create_argument: Any | Unset = UNSET
    interface_views: list[JsInterfaceView] | Unset = UNSET
    witness_parties: list[str] | Unset = UNSET
    signatories: list[str] | Unset = UNSET
    observers: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        offset = self.offset

        node_id = self.node_id

        contract_id = self.contract_id

        template_id = self.template_id

        created_event_blob = self.created_event_blob

        created_at = self.created_at

        package_name = self.package_name

        representative_package_id = self.representative_package_id

        acs_delta = self.acs_delta

        contract_key = self.contract_key

        create_argument = self.create_argument

        interface_views: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.interface_views, Unset):
            interface_views = []
            for interface_views_item_data in self.interface_views:
                interface_views_item = interface_views_item_data.to_dict()
                interface_views.append(interface_views_item)

        witness_parties: list[str] | Unset = UNSET
        if not isinstance(self.witness_parties, Unset):
            witness_parties = self.witness_parties

        signatories: list[str] | Unset = UNSET
        if not isinstance(self.signatories, Unset):
            signatories = self.signatories

        observers: list[str] | Unset = UNSET
        if not isinstance(self.observers, Unset):
            observers = self.observers

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "offset": offset,
                "nodeId": node_id,
                "contractId": contract_id,
                "templateId": template_id,
                "createdEventBlob": created_event_blob,
                "createdAt": created_at,
                "packageName": package_name,
                "representativePackageId": representative_package_id,
                "acsDelta": acs_delta,
            }
        )
        if contract_key is not UNSET:
            field_dict["contractKey"] = contract_key
        if create_argument is not UNSET:
            field_dict["createArgument"] = create_argument
        if interface_views is not UNSET:
            field_dict["interfaceViews"] = interface_views
        if witness_parties is not UNSET:
            field_dict["witnessParties"] = witness_parties
        if signatories is not UNSET:
            field_dict["signatories"] = signatories
        if observers is not UNSET:
            field_dict["observers"] = observers

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.js_interface_view import JsInterfaceView

        d = dict(src_dict)
        offset = d.pop("offset")

        node_id = d.pop("nodeId")

        contract_id = d.pop("contractId")

        template_id = d.pop("templateId")

        created_event_blob = d.pop("createdEventBlob")

        created_at = d.pop("createdAt")

        package_name = d.pop("packageName")

        representative_package_id = d.pop("representativePackageId")

        acs_delta = d.pop("acsDelta")

        contract_key = d.pop("contractKey", UNSET)

        create_argument = d.pop("createArgument", UNSET)

        _interface_views = d.pop("interfaceViews", UNSET)
        interface_views: list[JsInterfaceView] | Unset = UNSET
        if _interface_views is not UNSET:
            interface_views = []
            for interface_views_item_data in _interface_views:
                interface_views_item = JsInterfaceView.from_dict(
                    interface_views_item_data
                )

                interface_views.append(interface_views_item)

        witness_parties = cast(list[str], d.pop("witnessParties", UNSET))

        signatories = cast(list[str], d.pop("signatories", UNSET))

        observers = cast(list[str], d.pop("observers", UNSET))

        created_event = cls(
            offset=offset,
            node_id=node_id,
            contract_id=contract_id,
            template_id=template_id,
            created_event_blob=created_event_blob,
            created_at=created_at,
            package_name=package_name,
            representative_package_id=representative_package_id,
            acs_delta=acs_delta,
            contract_key=contract_key,
            create_argument=create_argument,
            interface_views=interface_views,
            witness_parties=witness_parties,
            signatories=signatories,
            observers=observers,
        )

        created_event.additional_properties = d
        return created_event

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DynamicSequencingParametersPayload(_message.Message):
    __slots__ = ("pbft_view_change_timeout",)
    PBFT_VIEW_CHANGE_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    pbft_view_change_timeout: _duration_pb2.Duration
    def __init__(self, pbft_view_change_timeout: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v0/participant_transfer.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/protocol/v0/participant_transfer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from . import common_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_common__pb2
from . import merkle_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_merkle__pb2
from . import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2
from ...time.v0 import time_proof_pb2 as com_dot_digitalasset_dot_canton_dot_time_dot_v0_dot_time__proof__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>com/digitalasset/canton/protocol/v0/participant_transfer.proto\x12#com.digitalasset.canton.protocol.v0\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x30\x63om/digitalasset/canton/protocol/v0/common.proto\x1a\x30\x63om/digitalasset/canton/protocol/v0/merkle.proto\x1a\x34\x63om/digitalasset/canton/protocol/v0/sequencing.proto\x1a\x30\x63om/digitalasset/canton/time/v0/time_proof.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"k\n\nTransferId\x12#\n\rorigin_domain\x18\x01 \x01(\tR\x0coriginDomain\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"g\n\x1aTransferOutMediatorMessage\x12I\n\x04tree\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v0.TransferViewTreeR\x04tree\"f\n\x19TransferInMediatorMessage\x12I\n\x04tree\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v0.TransferViewTreeR\x04tree\"\xc6\x01\n\x10TransferViewTree\x12S\n\x0b\x63ommon_data\x18\x01 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.BlindableNodeR\ncommonData\x12]\n\x10participant_data\x18\x02 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.BlindableNodeR\x0fparticipantData\"\xff\x01\n\x15TransferOutCommonData\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12#\n\rorigin_domain\x18\x02 \x01(\tR\x0coriginDomain\x12\"\n\x0cstakeholders\x18\x03 \x03(\tR\x0cstakeholders\x12#\n\radmin_parties\x18\x04 \x03(\tR\x0c\x61\x64minParties\x12\x12\n\x04uuid\x18\x05 \x01(\tR\x04uuid\x12\'\n\x0forigin_mediator\x18\x06 \x01(\tR\x0eoriginMediator\"\x8a\x02\n\x0fTransferOutView\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12\x1c\n\tsubmitter\x18\x02 \x01(\tR\tsubmitter\x12\x1f\n\x0b\x63ontract_id\x18\x03 \x01(\tR\ncontractId\x12#\n\rtarget_domain\x18\x04 \x01(\tR\x0ctargetDomain\x12V\n\x11target_time_proof\x18\x05 \x01(\x0b\x32*.com.digitalasset.canton.time.v0.TimeProofR\x0ftargetTimeProof\"\xd9\x01\n\x14TransferInCommonData\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12#\n\rtarget_domain\x18\x02 \x01(\tR\x0ctargetDomain\x12\"\n\x0cstakeholders\x18\x03 \x03(\tR\x0cstakeholders\x12\x12\n\x04uuid\x18\x04 \x01(\tR\x04uuid\x12\'\n\x0ftarget_mediator\x18\x06 \x01(\tR\x0etargetMediator\"\xe9\x02\n\x0eTransferInView\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12\x1c\n\tsubmitter\x18\x02 \x01(\tR\tsubmitter\x12U\n\x08\x63ontract\x18\x03 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v0.SerializableContractR\x08\x63ontract\x12m\n\x19transfer_out_result_event\x18\x04 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.SignedContentR\x16transferOutResultEvent\x12\x36\n\x17\x63reating_transaction_id\x18\x05 \x01(\x0cR\x15\x63reatingTransactionIdBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v0.participant_transfer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0'
  _globals['_TRANSFERID']._serialized_start=388
  _globals['_TRANSFERID']._serialized_end=495
  _globals['_TRANSFEROUTMEDIATORMESSAGE']._serialized_start=497
  _globals['_TRANSFEROUTMEDIATORMESSAGE']._serialized_end=600
  _globals['_TRANSFERINMEDIATORMESSAGE']._serialized_start=602
  _globals['_TRANSFERINMEDIATORMESSAGE']._serialized_end=704
  _globals['_TRANSFERVIEWTREE']._serialized_start=707
  _globals['_TRANSFERVIEWTREE']._serialized_end=905
  _globals['_TRANSFEROUTCOMMONDATA']._serialized_start=908
  _globals['_TRANSFEROUTCOMMONDATA']._serialized_end=1163
  _globals['_TRANSFEROUTVIEW']._serialized_start=1166
  _globals['_TRANSFEROUTVIEW']._serialized_end=1432
  _globals['_TRANSFERINCOMMONDATA']._serialized_start=1435
  _globals['_TRANSFERINCOMMONDATA']._serialized_end=1652
  _globals['_TRANSFERINVIEW']._serialized_start=1655
  _globals['_TRANSFERINVIEW']._serialized_end=2016
# @@protoc_insertion_point(module_scope)
